@@ -2,7 +2,8 @@ from urge.base import ProcManager, action
 from path import Path
 
 
-def web_screenshot(url: str, target: str = "./", **kwargs) -> str:
+def web_screenshot(url: str, target: str = "./", use_mobile=True,**kwargs) -> str:
+
     from playwright.sync_api import sync_playwright
     from datetime import datetime
 
@@ -18,9 +19,14 @@ def web_screenshot(url: str, target: str = "./", **kwargs) -> str:
             ' result.'
         )
         browser = browser_type.launch(headless=True)
+        if not use_mobile:
+            iphone_11 = {}
+
         context = browser.new_context(**iphone_11)
         page = context.new_page()
-        page.set_viewport_size({"width": 375, "height": 635})
+        if use_mobile:
+            page.set_viewport_size({"width": 375, "height": 635})
+
         page.goto(url, wait_until="networkidle")
         # page.screenshot(path=f'./example-{browser_type.name}haha.png')
         target = Path(target) 
