@@ -8,7 +8,7 @@ import typing as t
 
 def get_weather(city, ascii_graphs: bool = True, lang: str = "en", **kwargs) -> dict:
     res = httpx.get(
-        f'http://wttr.in/{city}?lang={lang}{ "&T0" if ascii_graphs else "&format=j1"}'
+        f'https://wttr.in/{city}?lang={lang}{ "&T0" if ascii_graphs else "&format=j1"}'
     )
     return dict(res=res, ascii_graphs=ascii_graphs)
 
@@ -18,10 +18,10 @@ def ret_weather(
 ) -> t.Union[str, float]:
     if ascii_graphs:
         pq = PyQuery(res.text)
-        result = pq.find('pre')
+        result = pq.find("pre")
         return str(result.text(squash_space=False))
-    temp = res.json().get('current_condition')
-    return float(temp[0].get('FeelsLikeC'))
+    temp = res.json().get("current_condition")
+    return float(temp[0].get("FeelsLikeC"))
 
 
 def get_now_temp(city: str, ascii_graphs: bool = True):
