@@ -1,5 +1,5 @@
 import os
-import json
+# import json
 import httpx
 from httpx import Response
 import typing as t
@@ -18,18 +18,19 @@ from dao.errors import ServiceError
 
 TRANS_URL = "https://ke.study.163.com/code/textTrans"
 OCR_URL = "https://ke.study.163.com/code/ocrTrans"
+PIC_TRAN = "https://ke.study.163.com/code/ocrTransApiTmp"
 FREE_MAP = {
     "trans": TransConfig(api=TRANS_URL),
     "ocr": OCRConfig(api=OCR_URL),
     "receipt": OCRReceipt(api=""),
     "table": OCRTableConfig(api=""),
-    "pictrans": OCRPicTrans(api=""),
+    "pictrans": OCRPicTrans(api=PIC_TRAN),
 }
 
 
 def post_builder(name, **kwd):
     token = os.getenv("token") or os.getenv("XXX")
-    # token = "tYwB%2FcQm2vlyCP1oP%2FRujV%2FPGfbkexMUPhrT%2BtOkIOmcEvbrs%2BuXh5XOk78v%2FGS9i%2B1dNra7zbXZp75%2BiyTT3LaQioa7GNhh5tXe9k%2FBFj8%3D"
+    # token = "tYwB%2FcQm2vlyCP1oP%2FRujYKV%2FCtDngeO7RRo07QT7XGcEvbrs%2BuXh5XOk78v%2FGS9nXL4dRS37%2FYnMrfJkon%2FQMHchXft0jdhFkmt7us7Gvc%3D"
     if token:
         _token = {"token": token}
 
@@ -43,9 +44,12 @@ def post_builder(name, **kwd):
                 headers=_token,
                 params={**_query, **_config.CONFIG, **kwd},
             )
-            resp = httpx.post(**_params).json()
-            code = int(resp["code"])
-            content = resp["data"]
+            resp = httpx.post(**_params)
+            _resp =resp.json() 
+            code = int(_resp["code"])
+            if code != 200:
+                raise Exception("Something wrong with XJ's service wraper")
+            content = _resp["data"]
 
             return Result(Response(content=content, status_code=code))
 
